@@ -1,4 +1,4 @@
-# load GOTTCHA assignments
+# load BWA assignments
 #
 
 # projects
@@ -7,15 +7,15 @@ data_file <- "../test_data/test_table_bwa.txt"
 
 # read em
 #
-the_list <- load_bwa_assignments(data_file)
+the_list <- load_edge_assignments(data_file, type = 'bwa')
 
 # tests
 #
 expect_that(length(the_list), equals(8))
-#
+
 expect_that(names(the_list[8]), equals("Project_SSputum-no-RAB"))
 
 #
 # test the failure
 #
-expect_that(load_bwa_assignments("../test_data/nonexistentfile.txt"), throws_error())
+expect_that(load_edge_assignments("../test_data/nonexistentfile.txt", type = 'bwa'), throws_error())
