@@ -1,4 +1,4 @@
-# load GOTTCHA assignments
+# load DIAMOND assignments
 #
 
 # projects
@@ -7,15 +7,16 @@ data_file <- "../test_data/test_table_kraken.txt"
 
 # read em
 #
-the_list <- load_kraken_assignments(data_file)
+the_list <- load_edge_assignments(data_file, type = 'kraken')
 
 # tests
 #
 expect_that(length(the_list), equals(8))
 
+print(paste('kraken'))
 expect_that(names(the_list[8]), equals("Project_SSputum-no-RAB"))
 
 #
 # test the failure
 #
-expect_that(load_kraken_assignments("../test_data/nonexistentfile.txt"), throws_error())
+expect_that(load_edge_assignments("../test_data/nonexistentfile.txt", type = 'kraken'), throws_error())
