@@ -28,8 +28,7 @@ projects <- data.frame(folder = projects[ - (grep(digit_pattern, projects$folder
 # accessions (projects_id)
 #
 name_pattern <- paste(".*", .Platform$file.sep, "(.*)", sep = "")
-projects$accession <- paste("Project_", stringr::str_match(projects$folder,
-                                                           name_pattern)[, 2], sep = "")
+projects$accession <- paste0("Project_", gsub(name_pattern, "\\1", projects$folder, perl = T))
 #
 # taxonomic assignments
 #
